#Instruction how to use xyzcalculator
##Section telling how to install the module
<p>Just write pip install argscalculator</p>
##Section telling how to use the module
<p>Open terminal and go to directory of which you are using this module. Now  pass the arrguments --x (any float value) --y (any float value) --o (any mathematical function ,eg add , sub , mul , div)
</p>
